# API Reference

## Classes

```{eval-rst}
.. currentmodule:: ess.nmx

.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

```

## Top-level functions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:

```

## Submodules

```{eval-rst}
.. autosummary::
   :toctree: ../generated/modules
   :template: module-template.rst
   :recursive:

   data
   mcstas
   types
   mtz_io
   scaling
   configurations

```
